@@ -5,13 +5,15 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import cdk8s._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk8s-plus", "0.27.0", __name__[0:-6], "cdk8s-plus@0.27.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "cdk8s-plus", "0.29.0", __name__[0:-6], "cdk8s-plus@0.29.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
